# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap(
    {
        "address_line": "AddressLine",
        "city": "City",
        "state_province_code": "StateProvinceCode",
        "postal_code": "PostalCode",
        "country_code": "CountryCode",
    }
)
class ShipFromAddress(BaseModel):
    """Ship from Address Container.  The package will be originating from or being shipped from this address. The shipment will be rated from this origin address to the destination ship to address.

    :param address_line: The Ship from street address including name and number (when applicable). 35 characters are accepted, but for return Shipment only 30 characters will be printed on the label.
    :type address_line: List[str]
    :param city: The Ship from city. 30 characters are accepted, but for return Shipment only 15 characters will be printed on the label.  Required if ShipFrom is supplied
    :type city: str
    :param state_province_code: Origin location's state or province code.  Required if ShipFrom is supplied, and ShipFrom country or territory is US. If ShipFrom country or territory is US or CA, then the value must be a valid US State/ Canadian Province code. If the country or territory is Ireland, the StateProvinceCode will contain the county or territory. , defaults to None
    :type state_province_code: str, optional
    :param postal_code: The ship from locations postal code. 9 characters are accepted.  Required if ShipFrom is supplied and the ShipFrom country or territory is the US and Puerto Rico. For US and Puerto Rico, it must be valid 5 or 9 digit postal code. The character "-" may be used to separate the first five digits and the last four digits. If the ShipFrom country or territory is CA, then the postal code must be 6 alphanumeric characters whose format is A#A#A# where A is an uppercase letter and # is a digit. For all other countries or territories the postal code is optional and must be no more than 9 alphanumeric characters long. , defaults to None
    :type postal_code: str, optional
    :param country_code: Origin locations country or territory code.  Required if ShipFrom tag is supplied. For Return Shipment the country or territory code must meet the following conditions: - At least two of the following country or territory codes are the same: ShipTo, ShipFrom, and Shipper. - None of the following country or territory codes are the same and are a member of the EU: ShipTo, ShipFrom, and Shipper. - If any of the two following country or territory codes: ShipTo/ShipFrom/ Shipper are members in EU otherwise check if the shipper has Third country or territory Contract.
    :type country_code: str
    """

    def __init__(
        self,
        address_line: List[str],
        city: str,
        country_code: str,
        state_province_code: str = None,
        postal_code: str = None,
    ):
        self.address_line = address_line
        self.city = city
        if state_province_code is not None:
            self.state_province_code = state_province_code
        if postal_code is not None:
            self.postal_code = postal_code
        self.country_code = country_code
